@@ -1136,10 +1136,38 @@ class Node {
 			$this->lastError = getMessage('cannot_set_status') . getMessage('not_computer');
 			return NULL;
 		}
-		delete("DELETE FROM computershw WHERE nodes_id=" . $this->id);
-		foreach ($hwList as $hw) {
-			write("INSERT into computershw (nodes_id,hwkey,hwvalue) values (" . $this->id . "," . qstr($hw["hwkey"]) . "," . qstr($hw["hwvalue"]) . ")");
-		}
+        $update = True;
+        $db_hwList = $this->getHardware();
+
+        if (count($db_hwList) == count($hwList)) {
+            $update = False;
+            $new_hwList = array();
+            $new_db_hwList = array();
+
+            foreach ($hwList as $hw) {
+                array_push($new_hwList, $hw["hwkey"].":".$hw["hwvalue"]);
+            }
+            arsort($new_hwList);
+            foreach ($db_hwList as $hw){
+                array_push($new_db_hwList, $hw["hwkey"].":".$hw["hwvalue"]);
+            }
+            if (count(array_intersect($new_db_hwList,$new_hwList)) != count($new_hwList)) {
+                //update db
+                $update = True;
+            }
+        }
+
+        if ($update) {
+            $query = "DELETE FROM computershw WHERE nodes_id=" . $this->id . ";";
+
+            //delete("DELETE FROM computershw WHERE nodes_id=" . $this->id);
+            foreach ($hwList as $hw) {
+                $query .= "INSERT into computershw (nodes_id,hwkey,hwvalue) values (" . $this->id . "," . qstr($hw["hwkey"]) . "," . qstr($hw["hwvalue"]) . ");";
+                //write("INSERT into computershw (nodes_id,hwkey,hwvalue) values (" . $this->id . "," . qstr($hw["hwkey"]) . "," . qstr($hw["hwvalue"]) . ")");
+            }
+            //Here I use delete so the statement is executed all in once. this add the values as well.
+            delete($query);
+        }
 	}
 
 	/**
